==> 0.0.30.tar.gz: lib/src/maps.dart <==
class Maps {
  static const ADANA = '.svg';
  static const ADIYAMAN = '.svg';
  static const AFYONKARAHISAR = '.svg';
  static const AGRI = '.svg';
  static const AMASYA = '.svg';
  static const ANKARA = '06-ANKARA.svg';
  static const ANTALYA = '.svg';
  static const ARTVIN = '.svg';
  static const AYDIN = '.svg';
  static const BALIKESIR = '.svg';
  static const BILECIK = '.svg';
  static const BINGOL = '.svg';
  static const BITLIS = '.svg';
  static const BOLU = '.svg';
  static const BURDUR = '.svg';
  static const BURSA = '.svg';
  static const CANAKKALE = '.svg';
  static const CANKIRI = '.svg';
  static const CORUM = '.svg';
  static const DENIZLI = '.svg';
  static const DIYARBAKIR = '.svg';
  static const EDIRNE = '.svg';
  static const ELAZIG = '.svg';
  static const ERZINCAN = '24-ERZINCAN.svg';
  static const ERZURUM = '.svg';
  static const ESKISEHIR = '.svg';
  static const GAZIANTEP = '.svg';
  static const GIRESUN = '.svg';
  static const GUMUSHANE = '.svg';
  static const HAKKARI = '.svg';
  static const HATAY = '.svg';
  static const ISPARTA = '.svg';
  static const MERSIN = '.svg';
  static const ISTANBUL = '34-ISTANBUL.svg';
  static const IZMIR = '35-IZMIR.svg';
  static const KARS = '.svg';
  static const KASTAMONU = '.svg';
  static const KAYSERI = '.svg';
  static const KIRKLARELI = '.svg';
  static const KIRSEHIR = '.svg';
  static const KOCAELI = '.svg';
  static const KONYA = '42-KONYA.svg';
  static const KUTAHYA = '.svg';
  static const MALATYA = '.svg';
  static const MANISA = '.svg';
  static const KAHRAMANMARAS = '.svg';
  static const MARDIN = '.svg';
  static const MUGLA = '.svg';
  static const MUS = '.svg';
  static const NEVSEHIR = '.svg';
  static const NIGDE = '.svg';
  static const ORDU = '.svg';
  static const RIZE = '.svg';
  static const SAKARYA = '.svg';
  static const SAMSUN = '.svg';
  static const SIIRT = '.svg';
  static const SINOP = '.svg';
  static const SIVAS = '.svg';
  static const TEKIRDAG = '.svg';
  static const TOKAT = '.svg';
  static const TRABZON = '.svg';
  static const TUNCELI = '.svg';
  static const SANLIURFA = '.svg';
  static const USAK = '.svg';
  static const VAN = '.svg';
  static const YOZGAT = '.svg';
  static const ZONGULDAK = '.svg';
  static const AKSARAY = '.svg';
  static const BAYBURT = '.svg';
  static const KARAMAN = '.svg';
  static const KIRIKKALE = '.svg';
  static const BATMAN = '.svg';
  static const SIRNAK = '.svg';
  static const BARTIN = '.svg';
  static const ARDAHAN = '.svg';
  static const IGDIR = '.svg';
  static const YALOVA = '.svg';
  static const KARABUK = '.svg';
  static const KILIS = '.svg';
  static const OSMANIYE = '.svg';
  static const DUZCE = '.svg';
}

==> 0.0.51.tar.gz: lib/src/maps.dart <==
class Maps {
  static const ADANA = '.svg';
  static const ADIYAMAN = '.svg';
  static const AFYONKARAHISAR = '.svg';
  static const AGRI = '.svg';
  static const AMASYA = '.svg';
  static const ANKARA = '06-ANKARA.svg';
  static const ANTALYA = '.svg';
  static const ARTVIN = '.svg';
  static const AYDIN = '.svg';
  static const BALIKESIR = '.svg';
  static const BILECIK = '.svg';
  static const BINGOL = '.svg';
  static const BITLIS = '.svg';
  static const BOLU = '.svg';
  static const BURDUR = '.svg';
  static const BURSA = '.svg';
  static const CANAKKALE = '.svg';
  static const CANKIRI = '.svg';
  static const CORUM = '.svg';
  static const DENIZLI = '.svg';
  static const DIYARBAKIR = '.svg';
  static const EDIRNE = '.svg';
  static const ELAZIG = '.svg';
  static const ERZINCAN = '24-ERZINCAN.svg';
  static const ERZURUM = '.svg';
  static const ESKISEHIR = '.svg';
  static const GAZIANTEP = '.svg';
  static const GIRESUN = '.svg';
  static const GUMUSHANE = '.svg';
  static const HAKKARI = '.svg';
  static const HATAY = '.svg';
  static const ISPARTA = '.svg';
  static const MERSIN = '.svg';
  static const ISTANBUL = '34-ISTANBUL.svg';
  static const IZMIR = '35-IZMIR.svg';
  static const KARS = '.svg';
  static const KASTAMONU = '.svg';
  static const KAYSERI = '.svg';
  static const KIRKLARELI = '.svg';
  static const KIRSEHIR = '.svg';
  static const KOCAELI = '.svg';
  static const KONYA = '42-KONYA.svg';
  static const KUTAHYA = '.svg';
  static const MALATYA = '.svg';
  static const MANISA = '.svg';
  static const KAHRAMANMARAS = '.svg';
  static const MARDIN = '.svg';
  static const MUGLA = '.svg';
  static const MUS = '.svg';
  static const NEVSEHIR = '.svg';
  static const NIGDE = '.svg';
  static const ORDU = '.svg';
  static const RIZE = '.svg';
  static const SAKARYA = '.svg';
  static const SAMSUN = '55-SAMSUN.svg';
  static const SIIRT = '.svg';
  static const SINOP = '.svg';
  static const SIVAS = '.svg';
  static const TEKIRDAG = '.svg';
  static const TOKAT = '.svg';
  static const TRABZON = '.svg';
  static const TUNCELI = '.svg';
  static const SANLIURFA = '.svg';
  static const USAK = '.svg';
  static const VAN = '.svg';
  static const YOZGAT = '.svg';
  static const ZONGULDAK = '.svg';
  static const AKSARAY = '.svg';
  static const BAYBURT = '.svg';
  static const KARAMAN = '.svg';
  static const KIRIKKALE = '.svg';
  static const BATMAN = '.svg';
  static const SIRNAK = '.svg';
  static const BARTIN = '.svg';
  static const ARDAHAN = '.svg';
  static const IGDIR = '.svg';
  static const YALOVA = '.svg';
  static const KARABUK = '.svg';
  static const KILIS = '.svg';
  static const OSMANIYE = '.svg';
  static const DUZCE = '.svg';
}
